@@ -266,7 +266,7 @@ language: TypeScript
   fn make_diffs<'a>(
     grep: &'a AstGrep<StrDoc<SgLang>>,
     matcher: impl Matcher<SgLang>,
-    fixer: &Fixer<String, SgLang>,
+    fixer: &Fixer<SgLang>,
   ) -> Vec<Diff<'a>> {
     let root = grep.root();
     Visitor::new(&matcher)
@@ -288,8 +288,8 @@ rule:
         - pattern: $A++
 fix: ($B, lifecycle.update(['$A']))",
     );
-    let matcher = config.matcher;
-    let fixer = config.fixer.unwrap();
+    let mut matcher = config.matcher;
+    let fixer = matcher.fixer.take().unwrap();
     let diffs = make_diffs(&root, matcher, &fixer);
     let ret = apply_rewrite(diffs);
     assert_eq!(ret, "let a = () => (c++, lifecycle.update(['c']))");
