@@ -1,10 +1,10 @@
 mod combined;
-mod constraints;
 mod fixer;
 mod maybe;
 mod rule;
 mod rule_collection;
 mod rule_config;
+mod rule_core;
 mod transform;
 
 use serde::Deserialize;
@@ -19,8 +19,7 @@ pub use rule::DeserializeEnv;
 pub use rule::{Rule, RuleSerializeError, SerializableRule};
 pub use rule_collection::RuleCollection;
 pub use rule_config::{
-  RuleConfig, RuleConfigError, RuleWithConstraint, SerializableRuleConfig, SerializableRuleCore,
-  Severity,
+  RuleConfig, RuleConfigError, RuleCore, SerializableRuleConfig, SerializableRuleCore, Severity,
 };
 pub use transform::Transformation;
 
