@@ -3,10 +3,13 @@ pub mod referent_rule;
 mod relational_rule;
 mod stop_by;
 
-use crate::maybe::Maybe;
 pub use deserialize_env::DeserializeEnv;
+pub use relational_rule::Relation;
+pub use stop_by::StopBy;
+
+use crate::maybe::Maybe;
 use referent_rule::{ReferentRule, ReferentRuleError};
-use relational_rule::{Follows, Has, Inside, Precedes, Relation};
+use relational_rule::{Follows, Has, Inside, Precedes};
 
 use ast_grep_core::language::Language;
 use ast_grep_core::matcher::{KindMatcher, KindMatcherError, RegexMatcher, RegexMatcherError};
