@@ -1,7 +1,6 @@
 use crate::FrontEndLanguage;
 
-use ast_grep_config::{RuleWithConstraint, SerializableRuleCore};
-use ast_grep_core::replacer::IndentSensitive;
+use ast_grep_config::{DeserializeEnv, RuleCore, SerializableRuleCore};
 use ast_grep_core::source::{Content, Doc, Edit, TSParseError};
 use ast_grep_core::Language;
 use napi::anyhow::Error;
@@ -29,19 +28,17 @@ pub struct NapiConfig {
 }
 
 impl NapiConfig {
-  pub fn parse_with(
-    self,
-    language: FrontEndLanguage,
-  ) -> NapiResult<RuleWithConstraint<FrontEndLanguage>> {
+  pub fn parse_with(self, language: FrontEndLanguage) -> NapiResult<RuleCore<FrontEndLanguage>> {
     let lang = self.language.unwrap_or(language);
     let rule = SerializableRuleCore {
-      language: lang,
       rule: serde_json::from_value(self.rule)?,
       constraints: self.constraints.map(serde_json::from_value).transpose()?,
       transform: self.transform.map(serde_json::from_value).transpose()?,
       utils: self.utils.map(serde_json::from_value).transpose()?,
+      fix: None,
     };
-    rule.get_matcher(&Default::default()).map_err(|e| {
+    let env = DeserializeEnv::new(lang);
+    rule.get_matcher(env).map_err(|e| {
       let error = Error::from(e)
         .chain()
         .map(ToString::to_string)
@@ -107,12 +104,6 @@ impl Content for Wrapper {
   }
 }
 
-impl IndentSensitive for Wrapper {
-  const NEW_LINE: u16 = b'\n' as u16;
-  const SPACE: u16 = b' ' as u16;
-  const TAB: u16 = b'\t' as u16;
-}
-
 fn pos_for_byte_offset(input: &[u16], byte_offset: usize) -> Point {
   let offset = byte_offset / 2;
   debug_assert!(offset <= input.len());
